@@ -93,13 +93,8 @@ LaunchDarklyParams: OrgParams = {
             display_name="Intuit: Production",
             region="us-west-2",
             arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-production",
-            ansible_bucket="launchdarkly-sym-ansible-prod-intuit",
-            aliases=[
-                "prod-intuit",
-                "production-intuit",
-                "intuit_production",
-                "intuit_production_use2",
-            ],
+            ansible_bucket="launchdarkly-sym-ansible-intuit-production",
+            aliases=["production-intuit", "intuit_production", "intuit_production_use2"],
         ),
         "intuit-dr": Profile(
             display_name="Intuit: DR",
@@ -112,7 +107,7 @@ LaunchDarklyParams: OrgParams = {
             display_name="Intuit: Staging",
             region="us-west-2",
             arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-staging",
-            ansible_bucket="launchdarkly-sym-ansible-staging-intuit",
+            ansible_bucket="launchdarkly-sym-ansible-intuit-staging",
             aliases=["staging-intuit", "intuit_staging", "intuit_staging_use2"],
         ),
         "production_apac": Profile(
